#ifndef NT2_INCLUDE_FUNCTIONS_J0_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_J0_HPP_INCLUDED

#include <nt2/bessel/include/functions/j0.hpp>

#endif
